@@ -24,7 +24,7 @@ Created on Jun 30, 2011
 '''
 
 from occi.backend import UserDefinedMixinBackend
-from occi.core_model import Resource, Link, Mixin, Category
+from occi.core_model import Resource, Link, Mixin
 from tornado.web import HTTPError
 import uuid
 
@@ -196,7 +196,7 @@ def update_collection(mixin, old_entities, new_entities, registry):
     for entity in unique(new_entities, old_entities):
         entity.mixins.append(mixin)
         backend = registry.get_backend(mixin)
-        backend.add_entity(entity)
+        backend.create(entity)
     del(new_entities)
 
 
@@ -218,10 +218,10 @@ def replace_collection(mixin, old_entities, new_entities, registry):
     for entity in unique(new_entities, old_entities):
         entity.mixins.append(mixin)
         backend = registry.get_backend(mixin)
-        backend.add_entity(entity)
+        backend.create(entity)
     for entity in unique(old_entities, new_entities):
         backend = registry.get_backend(mixin)
-        backend.remove_entity(entity)
+        backend.delete(entity)
         entity.mixins.remove(mixin)
     del(new_entities)
 
@@ -240,7 +240,7 @@ def delete_from_collection(mixin, entities, registry):
 
     for entity in intersect(entities, registry.get_resources()):
         backend = registry.get_backend(mixin)
-        backend.remove_entity(entity)
+        backend.delete(entity)
         entity.mixins.remove(mixin)
 
 
@@ -337,18 +337,15 @@ def append_mixins(mixins, registry):
             raise AttributeError('Needs to be of type Mixin.')
         if registry.get_category(mixin.location):
             raise AttributeError('Location overlaps with existing one.')
-        cat = Category(mixin.scheme, mixin.term, '', {}, '')
 
         try:
             registry.get_backend(mixin)
         except AttributeError:
             pass
         else:
-            del(cat)
             raise AttributeError('Category with same term, scheme already' +
                                  ' exists.')
 
-        del(cat)
         registry.set_backend(mixin, UserDefinedMixinBackend())
 
 
